@@ -18,6 +18,8 @@ class TestStarrocks(Validator):
             "DISTRIBUTED BY HASH (col1) PROPERTIES ('replication_num'='1')",
             "PRIMARY KEY (col1) DISTRIBUTED BY HASH (col1)",
             "DUPLICATE KEY (col1, col2) DISTRIBUTED BY HASH (col1)",
+            "UNIQUE KEY (col1, col2) PARTITION BY RANGE (col1) (START ('2024-01-01') END ('2024-01-31') EVERY (INTERVAL 1 DAY)) DISTRIBUTED BY HASH (col1)",
+            "UNIQUE KEY (col1, col2) PARTITION BY RANGE (col1, col2) (START ('1') END ('10') EVERY (1), START ('10') END ('100') EVERY (10)) DISTRIBUTED BY HASH (col1)",
         ]
 
         for properties in ddl_sqls:
@@ -31,6 +33,9 @@ class TestStarrocks(Validator):
         self.validate_identity(
             "CREATE TABLE foo (col0 DECIMAL(9, 1), col1 DECIMAL32(9, 1), col2 DECIMAL64(18, 10), col3 DECIMAL128(38, 10)) DISTRIBUTED BY HASH (col1) BUCKETS 1"
         )
+        self.validate_identity(
+            "CREATE TABLE foo (col1 LARGEINT) DISTRIBUTED BY HASH (col1) BUCKETS 1"
+        )
 
     def test_identity(self):
         self.validate_identity("SELECT CAST(`a`.`b` AS INT) FROM foo")
